@@ -13,6 +13,7 @@
 #import "VLCDonationCreditCardViewController.h"
 #import "VLCStripeController.h"
 #import "VLCCurrency.h"
+#import "VLCPrice.h"
 #import "VLC-Swift.h"
 
 #pragma clang diagnostic push
@@ -27,7 +28,10 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
 @interface VLCDonationCreditCardViewController () <VLCStripeControllerDelegate, ASWebAuthenticationPresentationContextProviding, UITextFieldDelegate>
 {
     NSNumber *_donationAmount;
+    VLCPrice *_price;
     VLCCurrency *_currency;
+    BOOL _recurring;
+
     VLCStripeController *_stripeController;
     ASWebAuthenticationSession *_webAuthenticationSession;
 
@@ -42,7 +46,7 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
 - (void)viewDidLoad {
     [super viewDidLoad];
 
-    _stripeController = [[VLCStripeController alloc] init];
+    _stripeController = [[VLCAppCoordinator sharedInstance] stripeController];
     _stripeController.delegate = self;
 
     self.creditCardNumberLabel.text = NSLocalizedString(@"DONATION_CC_NUM", nil);
@@ -97,7 +101,7 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
 - (void)updateColors
 {
     ColorPalette *colors = PresentationTheme.current.colors;
-    _continueButton.backgroundColor = colors.orangeUI;
+    _continueButton.backgroundColor = [UIColor grayColor];
     [_continueButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
     _continueButton.layer.cornerRadius = 5.;
     _creditCardNumberField.backgroundColor = colors.background;
@@ -108,6 +112,7 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
     _expiryDateYearField.layer.borderColor = colors.textfieldBorderColor.CGColor;
     _cvvField.backgroundColor = colors.background;
     _cvvField.layer.borderColor = colors.textfieldBorderColor.CGColor;
+    _activityIndicator.color = colors.orangeUI;
 }
 
 - (void)hideInputElements:(BOOL)bValue
@@ -165,8 +170,16 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
     _currency = currency;
 }
 
+- (void)setPrice:(VLCPrice *)selectedPrice withCurrency:(VLCCurrency *)currency recurring:(BOOL)recurring
+{
+    _price = selectedPrice;
+    _currency = currency;
+    _recurring = recurring;
+}
+
 - (void)viewWillAppear:(BOOL)animated
 {
+    _stripeController.delegate = self;
     [super viewWillAppear:animated];
 
     NSNumberFormatter *formatter = [[NSNumberFormatter alloc] init];
@@ -174,7 +187,13 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
     formatter.currencySymbol = _currency.localCurrencySymbol;
     formatter.maximumFractionDigits = 0;
 
-    self.titleLabel.text = [NSString stringWithFormat:NSLocalizedString(@"DONATION_AMOUNT", nil), [formatter stringFromNumber:_donationAmount]];
+    NSNumber *amount = _price ? _price.amount : _donationAmount;
+    if (_recurring) {
+        self.titleLabel.text = [NSString stringWithFormat:NSLocalizedString(@"DONATION_AMOUNT", nil),
+                                [NSString stringWithFormat:NSLocalizedString(@"DONATION_MONTHLY_FORMAT", nil), [formatter stringFromNumber:amount]]];
+    } else {
+        self.titleLabel.text = [NSString stringWithFormat:NSLocalizedString(@"DONATION_AMOUNT", nil), [formatter stringFromNumber:amount]];
+    }
     [self hideInputElements:NO];
 }
 
@@ -182,6 +201,7 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
 {
     // American Express cards have 4 digits for the CVV and only 15 digits
     _continueButton.enabled = _cvvField.text.length >= 3 && _expiryDateMonthField.text.length == 2 && _expiryDateYearField.text.length == 2 && _creditCardNumberField.text.length >= 15;
+    _continueButton.backgroundColor = _continueButton.enabled ? PresentationTheme.current.colors.orangeUI : [UIColor grayColor];
 }
 
 - (IBAction)continueButtonAction:(id)sender
@@ -194,12 +214,15 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
                                      exprMonth:self.expiryDateMonthField.text
                                      exprYear:self.expiryDateYearField.text
                                     forAmount:_donationAmount
-                                     currency:_currency];
+                                        price:_price
+                                     currency:_currency
+                                    recurring:_recurring];
 }
 
 #pragma mark - stripe controller delegation
 
-- (void)stripeProcessingSucceeded {
+- (void)stripeProcessingSucceeded
+{
     [self.activityIndicator stopAnimating];
 
     [self.confettiView startConfetti];
@@ -254,6 +277,11 @@ UITextContentType const UITextContentTypeCreditCardSecurityCode = @"UITextConten
                 if ([queryItem.name isEqualToString:@"payment_intent"]) {
                     [self->_stripeController continueWithPaymentIntent:queryItem.value];
                     break;
+                } else if ([queryItem.name isEqualToString:@"setup_intent"]) {
+                    [self->_stripeController continueWithSetupIntent:queryItem.value];
+                    break;
+                } else {
+                    APLog(@"invalid query item name: %@", queryItem.name);
                 }
             }
         }
