@@ -59,6 +59,18 @@ NSString *callbackURLString = @"vlcpay://3ds";
     [_sessionManager invalidateSessionCancelingTasks:YES resetSession:YES];
 }
 
+- (BOOL)currentLocaleIsEmbargoed
+{
+    NSString *countryCode = [[[NSLocale currentLocale] countryCode] uppercaseString];
+    NSArray *embargoedCountries = @[@"CU", @"IR", @"KP", @"SD", @"SY"]; // Cuba, Iran, North Korea, Sudan, Syria
+    for (NSString *embargoedCountry in embargoedCountries) {
+        if ([embargoedCountry isEqualToString:countryCode]) {
+            return YES;
+        }
+    }
+    return NO;
+}
+
 #pragma mark - apple pay internals
 
 - (void)processPayment:(PKPayment *)payment
@@ -369,6 +381,9 @@ NSString *callbackURLString = @"vlcpay://3ds";
     }
                   failure:^(NSURLSessionTask *task, NSError *error) {
         APLog(@"%s: %@", __func__, error.localizedDescription);
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
     }];
 }
 
@@ -405,6 +420,9 @@ NSString *callbackURLString = @"vlcpay://3ds";
     }
                   failure:^(NSURLSessionTask *task, NSError *error) {
         APLog(@"%s: %@", __func__, error.localizedDescription);
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
     }];
 }
 
@@ -420,6 +438,9 @@ NSString *callbackURLString = @"vlcpay://3ds";
     }
                   failure:^(NSURLSessionTask *task, NSError *error) {
         APLog(@"%s: %@", __func__, error.localizedDescription);
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
     }];
 }
 
@@ -440,13 +461,21 @@ NSString *callbackURLString = @"vlcpay://3ds";
     }
                   failure:^(NSURLSessionTask *task, NSError *error) {
         APLog(@"%s: %@", __func__, error.localizedDescription);
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
     }];
 }
 
 - (void)requestCurrentCustomerSubscription
 {
     if (_customerID == nil) {
-        // we will be called again as soon as the customer is loaded
+        // let's check if there is a customer stored that wasn't loaded yet
+        NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
+        _customerID = [defaults stringForKey:kVLCDonationAnonymousCustomerID];
+        if (_customerID != nil) {
+            [self handleCustomerToContinueWithTarget:self selector:@selector(requestCurrentCustomerSubscription)];
+        }
         return;
     }
     [_sessionManager GET:[NSString stringWithFormat:@"subscriptions?customer=%@", _customerID]
@@ -468,6 +497,9 @@ NSString *callbackURLString = @"vlcpay://3ds";
     }
                  failure:^(NSURLSessionTask *task, NSError *error) {
         APLog(@"%s: %@", __func__, error.localizedDescription);
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
     }];
 }
 
@@ -486,8 +518,10 @@ NSString *callbackURLString = @"vlcpay://3ds";
         });
     }
                   failure:^(NSURLSessionTask *task, NSError *error) {
-        [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
         APLog(@"%s: %@", __func__, error.localizedDescription);
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
     }];
 }
 
@@ -503,7 +537,9 @@ NSString *callbackURLString = @"vlcpay://3ds";
         }
     }
                     failure:^(NSURLSessionTask *task, NSError *error) {
-        [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
         APLog(@"%s: %@", __func__, error.localizedDescription);
     }];
 }
@@ -532,6 +568,9 @@ NSString *callbackURLString = @"vlcpay://3ds";
     }
                  failure:^(NSURLSessionTask *task, NSError *error) {
         APLog(@"Error retrieving recurring pricelist: %@", error.localizedDescription);
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
     }];
 }
 
@@ -558,6 +597,9 @@ NSString *callbackURLString = @"vlcpay://3ds";
             }
                          failure:^(NSURLSessionTask *task, NSError *error) {
                 APLog(@"Error reloading customer: %@", error.localizedDescription);
+                dispatch_async(dispatch_get_main_queue(), ^{
+                    [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+                });
             }];
         } else {
 #pragma clang diagnostic push
@@ -586,6 +628,9 @@ NSString *callbackURLString = @"vlcpay://3ds";
     }
                   failure:^(NSURLSessionTask *task, NSError *error) {
         APLog(@"Error creating customer: %@", error.localizedDescription);
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate stripeProcessingFailedWithError:error.localizedDescription];
+        });
     }];
 }
 
