@@ -35,6 +35,16 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell> {
         editButton.accessibilityHint = NSLocalizedString("BUTTON_EDIT_HINT", comment: "")
         return editButton
     }()
+    
+    private lazy var historyButton: UIBarButtonItem = {
+        var historyButton = UIBarButtonItem(image: UIImage(named: "HistoryClock"),
+                                     style: .plain, target: self,
+                                     action: #selector(handleHistory))
+        historyButton.tintColor = PresentationTheme.current.colors.orangeUI
+        historyButton.accessibilityLabel = NSLocalizedString("BUTTON_HISTORY", comment: "")
+        historyButton.accessibilityHint = NSLocalizedString("BUTTON_HISTORY_HINT", comment: "")
+        return historyButton
+    }()
 
     private lazy var regroupButton: UIBarButtonItem = {
         var regroup = UIBarButtonItem(image: UIImage(named: "regroupMediaGroups"),
@@ -90,7 +100,7 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell> {
             rightBarButtons = [menuButton]
         } else {
             rightBarButtons = [editButton]
-            leftBarButtons = [sortButton]
+            leftBarButtons = [sortButton, historyButton]
         }
 
         if !rendererButton.isHidden {
@@ -140,9 +150,7 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell> {
 
     func updateButtonsFor(_ viewController: UIViewController) {
         var showButtons = false
-        if let mediaCategoryViewController = viewController as? MediaCategoryViewController,
-            !mediaCategoryViewController.isSearching {
-            showButtons = true
+        if let mediaCategoryViewController = viewController as? MediaCategoryViewController {
             showButtons = mediaCategoryViewController.isEmptyCollectionView() ? false : true
         }
 
@@ -184,6 +192,11 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell> {
 
         leftBarButtonItems.append(sortButton)
 
+        if let parentViewController = viewController.parent,
+           parentViewController is AudioViewController || parentViewController is VideoViewController {
+            leftBarButtonItems.append(historyButton)
+        }
+
         return leftBarButtonItems
     }
 
@@ -282,20 +295,20 @@ extension MediaViewController {
 
         if let mediaCategoryViewController = viewControllers[currentIndex] as? MediaCategoryViewController,
             mediaCategoryViewController.model is MediaGroupViewModel {
-            leftBarButtons = isEditing ? [regroupButton, selectAllButton] : [sortButton]
+            leftBarButtons = isEditing ? [regroupButton, selectAllButton] : [sortButton, historyButton]
             rightButtons = [editButton]
         } else if viewControllers[currentIndex] is ArtistAlbumCategoryViewController ||
                     viewControllers[currentIndex] is CollectionCategoryViewController {
             leftBarButtons = nil
             rightButtons = [editButton, sortButton]
         } else {
-            leftBarButtons = isEditing ? [selectAllButton] : [sortButton]
+            leftBarButtons = isEditing ? [selectAllButton] : [sortButton, historyButton]
             rightButtons = [editButton]
         }
 
         if #available(iOS 14.0, *) {
             rightButtons = [menuButton]
-            // No left buttons with UIMenu
+            // left button is History button
             if isEditing == false {
                 leftBarButtons = nil
             }
@@ -347,6 +360,12 @@ extension MediaViewController {
             mediaCategoryViewController.handleRegroup()
         }
     }
+    
+    @objc func handleHistory() {
+        let mediaType: VLCMLMediaType = viewControllers[currentIndex] is MovieCategoryViewController ? .video : .audio
+        let historyView = HistoryCategoryViewController(mediaLibraryService, mediaType: mediaType)
+        navigationController?.pushViewController(historyView, animated: true)
+    }
 
     @objc func handleSelectAll() {
         let controller: MediaCategoryViewController
@@ -459,6 +478,19 @@ extension MediaViewController {
         return selectAction
     }
 
+    @available(iOS 14.0, *)
+    func generateHistoryMenu() -> UIMenu {
+        let historyAction = UIAction(title: NSLocalizedString("BUTTON_HISTORY", comment: ""),
+                                     image: UIImage(systemName: "clock.arrow.2.circlepath")) { _ in
+            self.handleHistory()
+        }
+
+        historyAction.accessibilityLabel = NSLocalizedString("BUTTON_HISTORY", comment: "")
+        historyAction.accessibilityHint = NSLocalizedString("BUTTON_HISTORY_HINT", comment: "")
+
+        return UIMenu(options: .displayInline, children: [historyAction])
+    }
+
     @available(iOS 14.0, *)
     func generateMenu(viewController: MediaCategoryViewController?) -> UIMenu {
         guard let mediaCategoryViewController = viewController else {
@@ -474,6 +506,12 @@ extension MediaViewController {
             return UIMenu(options: .displayInline, children: rightMenuItems)
         }
 
+        if let parentViewController = viewController?.parent,
+           parentViewController is VideoViewController || parentViewController is AudioViewController {
+            let historyMenu = generateHistoryMenu()
+            rightMenuItems.append(historyMenu)
+        }
+
         let layoutSubMenu = generateLayoutMenu(with: mediaCategoryViewController)
         let sortSubMenu = generateSortMenu(with: mediaCategoryViewController)
 
