@@ -151,17 +151,21 @@ NSString *const VLCPlayerDisplayControllerHideMiniPlayer = @"VLCPlayerDisplayCon
     NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
     BOOL enforceFullscreen = [[defaults objectForKey:kVLCSettingVideoFullscreenPlayback] boolValue];
 
-    if (self.playbackController.fullscreenSessionRequested && enforceFullscreen) {
-        [self showFullscreenPlayback];
-        return;
-    }
-
     VLCMedia *currentMedia = _playbackController.currentlyPlayingMedia;
     VLCMLMedia *media = [VLCMLMedia mediaForPlayingMedia:currentMedia];
 
+    _playbackController.fullscreenSessionRequested = [media type] != VLCMLMediaTypeAudio;
+
+    if (self.playbackController.fullscreenSessionRequested && enforceFullscreen) {
+        [self setDisplayMode:VLCPlayerDisplayControllerDisplayModeFullscreen];
+    } else if ([media type] == VLCMLMediaTypeAudio && _playbackController.numberOfVideoTracks > 0) {
+        [self setDisplayMode:VLCPlayerDisplayControllerDisplayModeFullscreen];
+    }
+
     switch (self.displayMode) {
         case VLCPlayerDisplayControllerDisplayModeFullscreen:
-            if (media.type == VLCMLMediaTypeAudio) {
+            if ((media.type == VLCMLMediaTypeAudio || _playbackController.playAsAudio) &&
+                _playbackController.numberOfVideoTracks == 0) {
                 [self _presentAudioPlayerViewIfNeeded];
             } else {
                 [self _presentFullscreenPlaybackViewIfNeeded];
@@ -450,7 +454,10 @@ NSString *const VLCPlayerDisplayControllerHideMiniPlayer = @"VLCPlayerDisplayCon
                          }
                          completion:completionBlock];
     }
-    [playbackController savePlaybackState];
+
+    if (needsHide) {
+        [playbackController savePlaybackState];
+    }
 #endif
 }
 
@@ -531,7 +538,6 @@ NSString *const VLCPlayerDisplayControllerHideMiniPlayer = @"VLCPlayerDisplayCon
 - (void)videoPlayerViewControllerDidMinimize:(VLCVideoPlayerViewController *)videoPlayerViewController
 {
     [self closeFullscreenPlayback];
-    [self addPlayqueueToMiniPlayer];
 }
 
 - (BOOL)videoPlayerViewControllerShouldBeDisplayed:(VLCVideoPlayerViewController *)videoPlayerViewController
@@ -539,12 +545,19 @@ NSString *const VLCPlayerDisplayControllerHideMiniPlayer = @"VLCPlayerDisplayCon
     return self.displayMode == VLCPlayerDisplayControllerDisplayModeFullscreen;
 }
 
+- (void)videoPlayerViewControllerShouldSwitchPlayer:(VLCVideoPlayerViewController *)videoPlayerViewController
+{
+    [_movieViewController dismissViewControllerAnimated:[self shouldAnimate] completion:^{
+        [self setDisplayMode:VLCPlayerDisplayControllerDisplayModeFullscreen];
+        [self _presentFullscreenPlaybackViewIfNeeded];
+    }];
+}
+
 #pragma mark - AudioPlayerViewControllerDelegate
 
 - (void)audioPlayerViewControllerDidMinimize:(VLCAudioPlayerViewController *)audioPlayerViewController
 {
     [self closeAudioPlayer];
-    [self addPlayqueueToMiniPlayer];
 }
 
 - (void)audioPlayerViewControllerDidClose:(VLCAudioPlayerViewController *)audioPlayerViewController
@@ -559,6 +572,14 @@ NSString *const VLCPlayerDisplayControllerHideMiniPlayer = @"VLCPlayerDisplayCon
     return self.displayMode == VLCPlayerDisplayControllerDisplayModeFullscreen;
 }
 
+- (void)audioPlayerViewControllerShouldSwitchPlayer:(VLCAudioPlayerViewController *)audioPlayerViewController
+{
+    [_audioPlayerViewController dismissViewControllerAnimated:[self shouldAnimate] completion:^{
+        [self setDisplayMode:VLCPlayerDisplayControllerDisplayModeFullscreen];
+        [self _presentFullscreenPlaybackViewIfNeeded];
+    }];
+}
+
 #pragma mark - KeyCommands
 
 - (void)handlePlayPauseKeyInput
